unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls;

type
  TForm1 = class(TForm)
    LevelProgress0: TProgressBar;
    LevelProgress1: TProgressBar;
    GoButton: TButton;
    StatusLabel: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure GoButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

uses
  AIOUSB;

type
  TUSBAI1616Config = packed record
    ChannelRange: array[$0..$F] of Byte;
    CalibMode: Byte;
    TrigMode: Byte;
    StartStopCh: Byte;
    Oversample: Byte;
    HighChannels: Byte; //added for compatibility with the AI-MUX family
  end;

var
  DeviceIndex: LongWord;
  Config: TUSBAI1616Config;

procedure TForm1.FormCreate(Sender: TObject);
var
  Status, DeviceMask, PID: LongWord;
  I: Integer;

begin
  DeviceIndex := diNone;

  DeviceMask := GetDevices;
  for I := 0 to 31 do
    if (DeviceMask and (1 shl I)) <> 0 then begin
      Status := QueryDeviceInfo(I, @PID, nil, nil, nil, nil);
      if (Status = ERROR_SUCCESS) and (PID >= $8040) and (PID < $8060) then begin
        DeviceIndex := I;
        Break;
      end;
    end
  ;

  if DeviceIndex <> diNone then GoButton.Enabled := True;
end;

procedure TForm1.GoButtonClick(Sender: TObject);
var
  ADBuf: array[0..1] of Word; //For more noise resistance, oversample to a larger buffer and average.
  Status, ConfigSize, ADBufSize: LongWord;
  Scans: Integer;

begin
  GoButton.Enabled := False;

  ConfigSize := SizeOf(Config);
  ZeroMemory(@Config, ConfigSize);
  Config.ChannelRange[0] := $02; //0-5V.
  Config.ChannelRange[1] := $02; //0-5V.
  Config.CalibMode := $00; //Take actual data.
  Config.TrigMode := $00; //Software start single channels.
  Config.StartStopCh := $10; //Select channels 0 to 1.
  Config.Oversample := 0; //No oversample.
  Config.HighChannels := $00; //The high bits of the channel numbers on mux boards.
  ADC_SetConfig(DeviceIndex, @Config, ConfigSize);

  StatusLabel.Caption := 'Taking data...';
  StatusLabel.Repaint;

  ADBufSize := SizeOf(ADBuf);

  Scans := 0;
  repeat
    Status := GenericVendorRead(DeviceIndex, $BF, 0, 0, ADBufSize, @ADBuf[0]);
    if Status <> ERROR_SUCCESS then begin
      StatusLabel.Caption := 'Error ' + IntToStr(Status) + ', stopping.';
      Break;
    end;
    LevelProgress0.Position := ADBuf[0]; //counts from channel 0
    LevelProgress1.Position := ADBuf[1]; //counts from channel 1

    Inc(Scans);
    if Scans >= 10000 then begin
      StatusLabel.Caption := 'Stopping.';
      Break;
    end;
  until False;  

  GoButton.Enabled := True;
end;

end.
